Changelog — DaMa ML 1.0a1 documentation

# Changelog

## 1.0a

- Implemented Dagroup with dask arrays
- Added abstract class to manage drivers and groups
- Added driver Zarr
- Added driver Postgres
- Added driver Sqlite3
- Added driver HDF5
- Added driver CSV

## 0.1.1

- Implemented basic cross validator
- Implemented basic abstract class to manage keras, sklearn, lightGBM and xgboost
- Implemented iterators
- Testing dask with drivers
- Implemented basic dama-cli to manage datasets and models

## 0.1.0

- Initial version